@@ -32,11 +32,11 @@ from .literals import (
     TypeDefinitionFormatType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -694,7 +694,7 @@ class GetIntrospectionSchemaRequestRequestTypeDef(
 GetIntrospectionSchemaResponseTypeDef = TypedDict(
     "GetIntrospectionSchemaResponseTypeDef",
     {
-        "schema": bytes,
+        "schema": StreamingBody,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
